==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/dom/WindowOrWorkerGlobalScopeTrustedTypes.h <==
/*
 * Copyright (C) 2024 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#pragma once

#include "Supplementable.h"
#include <wtf/Forward.h>
#include <wtf/TZoneMalloc.h>
#include <wtf/WeakPtr.h>

namespace WebCore {

class TrustedTypePolicyFactory;
class DOMWindow;
class WeakPtrImplWithEventTargetData;
class WorkerGlobalScope;

template<typename> class ExceptionOr;

class WindowOrWorkerGlobalScopeTrustedTypes {
public:
    static ASCIILiteral workerGlobalSupplementName();
    static TrustedTypePolicyFactory* trustedTypes(DOMWindow&);
    static TrustedTypePolicyFactory* trustedTypes(WorkerGlobalScope&);
};

class WorkerGlobalScopeTrustedTypes : public Supplement<WorkerGlobalScope> {
    WTF_MAKE_TZONE_ALLOCATED(WorkerGlobalScopeTrustedTypes);
public:
    explicit WorkerGlobalScopeTrustedTypes(WorkerGlobalScope&);
    virtual ~WorkerGlobalScopeTrustedTypes();

    static WorkerGlobalScopeTrustedTypes* from(WorkerGlobalScope&);
    TrustedTypePolicyFactory* trustedTypes() const;

    void prepareForDestruction();

    static ASCIILiteral supplementName() { return WindowOrWorkerGlobalScopeTrustedTypes::workerGlobalSupplementName(); }

private:
    bool isWorkerGlobalScopeTrustedTypes() const final { return true; }

    WeakPtr<WorkerGlobalScope, WeakPtrImplWithEventTargetData> m_scope;
    mutable RefPtr<TrustedTypePolicyFactory> m_trustedTypes;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::WorkerGlobalScopeTrustedTypes)
    static bool isType(const WebCore::SupplementBase& supplement) { return supplement.isWorkerGlobalScopeTrustedTypes(); }
SPECIALIZE_TYPE_TRAITS_END()

==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/WebCore/dom/WindowOrWorkerGlobalScopeTrustedTypes.h <==
/*
 * Copyright (C) 2024 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#pragma once

#include "Supplementable.h"
#include <wtf/Forward.h>
#include <wtf/TZoneMalloc.h>
#include <wtf/WeakPtr.h>

namespace WebCore {

class TrustedTypePolicyFactory;
class DOMWindow;
class WeakPtrImplWithEventTargetData;
class WorkerGlobalScope;

template<typename> class ExceptionOr;

class WindowOrWorkerGlobalScopeTrustedTypes {
public:
    static TrustedTypePolicyFactory* trustedTypes(DOMWindow&);
    static TrustedTypePolicyFactory* trustedTypes(WorkerGlobalScope&);
};

class WorkerGlobalScopeTrustedTypes : public Supplement<WorkerGlobalScope> {
    WTF_MAKE_TZONE_ALLOCATED(WorkerGlobalScopeTrustedTypes);
public:
    explicit WorkerGlobalScopeTrustedTypes(WorkerGlobalScope&);
    virtual ~WorkerGlobalScopeTrustedTypes();

    static WorkerGlobalScopeTrustedTypes* from(WorkerGlobalScope&);
    TrustedTypePolicyFactory* trustedTypes() const;

    void prepareForDestruction();

    static ASCIILiteral supplementName() { return "WorkerGlobalScopeTrustedTypes"_s; }

private:
    bool isWorkerGlobalScopeTrustedTypes() const final { return true; }

    WeakPtr<WorkerGlobalScope, WeakPtrImplWithEventTargetData> m_scope;
    mutable RefPtr<TrustedTypePolicyFactory> m_trustedTypes;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::WorkerGlobalScopeTrustedTypes)
    static bool isType(const WebCore::SupplementBase& supplement) { return supplement.isWorkerGlobalScopeTrustedTypes(); }
SPECIALIZE_TYPE_TRAITS_END()
